@@ -5,6 +5,10 @@ if sys.maxsize > 2 ** 32:
     import CloudKit
 
     class TestCKRecord (TestCase):
+        @min_sdk_level("10.11")
+        def testProtocols(self):
+            objc.protocolNamed('CKRecordKeyValueSetting')
+
         @min_os_level("10.10")
         def testClasses(self):
             self.assertHasAttr(CloudKit, "CKRecord")
